//
// Copyright 2001 Perforce Software.  All rights reserved.
//
// This file is part of Perforce - the FAST SCM System.
//
// p4wRunPane:
//   Methods to display run forms

#ifndef p4wRunPane_H
#define p4wRunPane_H

#include "p4wSpecPane.h"

class StrDict;

class p4wRunPane : public p4wSpecPane {

public:

	p4wRunPane( p4wView & ParentView, p4wRequest & Request );
	p4wRunPane( p4wView & ParentView, p4wRequest & Request, int unchecked );
	
	virtual		~p4wRunPane();

protected:

	void BeginForm( const char *title, StrBuf & action, char *path =0 );
	
	void EndForm();

	void BeginButtons();
	
	void EndButtons();
	
	void DoButton( const char *name, const char *value );
	
	void DoHidden( int listItem, const char *name, const char *value );
	
	void DoHidden( int listItem, const char *name, int value );
	
	void DoListItem( const char *item, int noSpan =0, 
		const char *ftype=NULL );
			
	void BeginFiles( const StrPtr &path, int noLeadingWs =0 );
	
	void EndFiles();
	
	void FilesIn( int all, int checked, const char *path, 
		const char *allText, int skipCol =0 );
	
	void BeginSelected( int optChecked, int filesChecked );
	
	void DoFile( int checked, StrPtr *filename, StrPtr *fileText, 
		const char *ftype=NULL );
	
	void BeginOptions();
	
	void BeginOptionChange( const char *text, int newRow =0, int sameCol =0 );
	
	void BeginFilesChange( const char *text );
	
	void BeginSelect( const char *value, const char *onFocus =0 );
	
	void DoOption( const char *text, const char *value =0 );
	
	void EndSelect();
	
	int FilesUnchecked() { return fUnchecked; };
	
	void DoCheckFiles( int checked );

	void DoCheckbox( int listItem, int checked, const char *name, 
		const char *value, const char *text, int newCol =0,
		int endRow =0, int splitCol =0 );
		
	void DoRadio( int listItem, int checked, const char *name, 
		const char *value, const char *text, int endCol =0,
		int endRow =0, const char *id =0, const char *height =0 );
		
	void DoText( const char *name, const char *value, int size, int endRow =0, 
		const char *onClick =0, const char *onFocus =0, 
		const char *onBlur =0, const char *id =0 );
	
	void DoComment( const char *text );
	
	void DoFileType( int useBox, const char *type );
	
	int fUnchecked;
	
	int fRedisplay;

	int fIsFirstFile;
	int fNeedsTRTD;
};

#endif // p4wRunPane_H
